Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ParseRange ¶
ParseRange parses a range string like "0-3,8-11" into a list of ints.
Types ¶
type Machine ¶
type Machine struct {
Threads []*Thread // All logical CPUs in the system
Cores []*Core // All physical cores
Dies []*Die // All dies
Sockets []*Socket // All physical packages
Nodes []*NUMANode // All NUMA nodes
}
Machine represents the entire system topology.
Sockets, Dies, Cores, and Threads exist in a hierarchy. NUMA nodes generally correspond to Dies, but this isn't guaranteed.
Click to show internal directories.
Click to hide internal directories.